@@ -186,7 +186,7 @@ static GtkItemFactoryEntry gkrellmms_factory[] =
   {N_("/Xmms.../Next"),                 NULL, toggles_func,  gkrellmms_next,     "<Item>"},
   {"/-",                                NULL, NULL,          0,        "<Separator>"},
   {N_("/Playlist Editor"),              NULL, open_playlist_cb, 0,        "<Item>"},
-  {N_("/GKrellMMS Options"),            NULL, open_playlist_cb, 0,        "<Item>"},
+  {N_("/GKrellMMS Options"),            NULL, open_options_cb, 0,        "<Item>"},
   {"/-",                                NULL, NULL,          0,        "<Separator>"},
   {N_("/Open file(s)"),                 NULL, toggles_func,  gkrellmms_eject,    "<Item>"},
   {N_("/Open Playlist"),                NULL, load_playlist_cb,  0,        "<Item>"},
